@@ -17,12 +17,10 @@ class Person:
     birthday: Union[datetime, date]
 
 
+@register_fixture(name="aliased_person_factory")
 class PersonFactory(DataclassFactory[Person]): ...
 
 
-person_factory_fixture = register_fixture(PersonFactory, name="aliased_person_factory")
-
-
 def test_person_factory(aliased_person_factory: PersonFactory) -> None:
     person_instance = aliased_person_factory.build()
     assert isinstance(person_instance, Person)
