@@ -55,6 +55,8 @@ from polyfactory.constants import (
 from polyfactory.exceptions import ConfigurationException, MissingBuildKwargException, ParameterException
 from polyfactory.field_meta import Null
 from polyfactory.fields import Fixture, Ignore, PostGenerated, Require, Use
+from polyfactory.utils._internal import is_attribute_overridden
+from polyfactory.utils.deprecation import warn_deprecation
 from polyfactory.utils.helpers import (
     flatten_annotation,
     get_collection_type,
@@ -63,7 +65,15 @@ from polyfactory.utils.helpers import (
     unwrap_optional,
 )
 from polyfactory.utils.model_coverage import CoverageContainer, CoverageContainerCallable, resolve_kwargs_coverage
-from polyfactory.utils.predicates import get_type_origin, is_literal, is_optional, is_safe_subclass, is_union
+from polyfactory.utils.predicates import (
+    get_type_origin,
+    is_forward_ref,
+    is_literal,
+    is_optional,
+    is_safe_subclass,
+    is_type_var,
+    is_union,
+)
 from polyfactory.utils.types import NoneType
 from polyfactory.value_generators.complex_types import handle_collection_type, handle_collection_type_coverage
 from polyfactory.value_generators.constrained_collections import (
@@ -166,6 +176,7 @@ class BaseFactory(ABC, Generic[T]):
     """
     Flag indicating whether to use the default value on a specific field, if provided.
     """
+    __forward_references__: ClassVar[dict[str, Any]] = {}
 
     __config_keys__: tuple[str, ...] = (
         "__check_model__",
@@ -177,6 +188,7 @@ class BaseFactory(ABC, Generic[T]):
         "__min_collection_length__",
         "__max_collection_length__",
         "__use_defaults__",
+        "__forward_references__",
     )
     """Keys to be considered as config values to pass on to dynamically created factories."""
 
@@ -230,6 +242,13 @@ class BaseFactory(ABC, Generic[T]):
                     raise ConfigurationException(
                         msg,
                     )
+            if not is_attribute_overridden(BaseFactory, cls, "__check_model__"):
+                warn_deprecation(
+                    "v2.22.0",
+                    deprecated_name="__check_model__",
+                    kind="default",
+                    alternative="set to `False` explicitly to keep existing behaviour",
+                )
             if cls.__check_model__:
                 cls._check_declared_fields_exist_in_model()
         else:
@@ -251,7 +270,10 @@ class BaseFactory(ABC, Generic[T]):
         if build_context is None:
             return {"seen_models": set()}
 
-        return copy.deepcopy(build_context)
+        return {
+            **build_context,
+            "seen_models": copy.copy(build_context["seen_models"]),
+        }
 
     @classmethod
     def _infer_model_type(cls) -> type[T] | None:
@@ -268,7 +290,7 @@ class BaseFactory(ABC, Generic[T]):
             b for b in get_original_bases(cls) if get_origin(b) and issubclass(get_origin(b), BaseFactory)
         )
         generic_args: Sequence[type[T]] = [
-            arg for factory_base in factory_bases for arg in get_args(factory_base) if not isinstance(arg, TypeVar)
+            arg for factory_base in factory_bases for arg in get_args(factory_base) if not is_type_var(arg)
         ]
         if len(generic_args) != 1:
             return None
@@ -448,7 +470,7 @@ class BaseFactory(ABC, Generic[T]):
         :returns: Boolean dictating whether the annotation is a batch factory type
         """
         origin = get_type_origin(annotation) or annotation
-        if is_safe_subclass(origin, Sequence) and (args := unwrap_args(annotation, random=cls.__random__)):
+        if is_safe_subclass(origin, Sequence) and (args := unwrap_args(annotation)):
             return len(args) == 1 and BaseFactory.is_factory_type(annotation=args[0])
         return False
 
@@ -748,7 +770,8 @@ class BaseFactory(ABC, Generic[T]):
         if field_build_parameters is None and cls.should_set_none_value(field_meta=field_meta):
             return None
 
-        unwrapped_annotation = unwrap_annotation(field_meta.annotation, random=cls.__random__)
+        unwrapped_annotation = unwrap_annotation(field_meta.annotation)
+        unwrapped_annotation = cls._resolve_forward_references(unwrapped_annotation)
 
         if is_literal(annotation=unwrapped_annotation) and (literal_args := get_args(unwrapped_annotation)):
             return cls.__random__.choice(literal_args)
@@ -764,7 +787,7 @@ class BaseFactory(ABC, Generic[T]):
                 build_context=build_context,
             )
 
-        if is_union(field_meta.annotation) and field_meta.children:
+        if (is_union(unwrapped_annotation) or is_union(field_meta.annotation)) and field_meta.children:
             seen_models = build_context["seen_models"]
             children = [child for child in field_meta.children if child.annotation not in seen_models]
 
@@ -839,7 +862,7 @@ class BaseFactory(ABC, Generic[T]):
         if provider := (provider_map.get(field_meta.annotation) or provider_map.get(unwrapped_annotation)):
             return provider()
 
-        if isinstance(unwrapped_annotation, TypeVar):
+        if is_type_var(unwrapped_annotation):
             return create_random_string(cls.__random__, min_length=1, max_length=10)
 
         if callable(unwrapped_annotation):
@@ -877,6 +900,8 @@ class BaseFactory(ABC, Generic[T]):
             return
 
         for unwrapped_annotation in flatten_annotation(field_meta.annotation):
+            unwrapped_annotation = cls._resolve_forward_references(unwrapped_annotation)  # noqa: PLW2901
+
             if unwrapped_annotation in (None, NoneType):
                 yield None
 
@@ -903,7 +928,7 @@ class BaseFactory(ABC, Generic[T]):
 
             elif (origin := get_type_origin(unwrapped_annotation)) and issubclass(origin, Collection):
                 if not field_meta.children:
-                    msg = "A subclass of Collection should always have children in it's field_meta"
+                    msg = "A subclass of Collection should always have children in its field_meta"
                     raise ParameterException(msg)
 
                 # We actually want to use the parent in cases where the collection is the parent
@@ -921,7 +946,7 @@ class BaseFactory(ABC, Generic[T]):
             ):
                 yield CoverageContainerCallable(provider)
 
-            elif isinstance(unwrapped_annotation, TypeVar):
+            elif is_type_var(unwrapped_annotation):
                 yield create_random_string(cls.__random__, min_length=1, max_length=10)
 
             elif callable(unwrapped_annotation):
@@ -934,6 +959,21 @@ class BaseFactory(ABC, Generic[T]):
                     msg,
                 )
 
+    @classmethod
+    def _resolve_forward_references(cls, annotation: Any) -> Any:
+        """Resolve forward references in the factory's model."""
+        if not cls.__forward_references__:
+            return annotation
+
+        if is_forward_ref(annotation):
+            return cls.__forward_references__.get(annotation.__forward_arg__, annotation)
+
+        # This is a workaround when forward references are resolved to strings
+        if isinstance(annotation, str):
+            return cls.__forward_references__.get(annotation, annotation)
+
+        return annotation
+
     @classmethod
     def should_set_none_value(cls, field_meta: FieldMeta) -> bool:
         """Determine whether a given model field_meta should be set to None.
