@@ -8,7 +8,13 @@ from typing_extensions import get_args, get_origin
 
 from polyfactory.constants import DEFAULT_RANDOM, TYPE_MAPPING
 from polyfactory.utils.deprecation import check_for_deprecated_parameters
-from polyfactory.utils.helpers import get_annotation_metadata, is_dataclass_instance, unwrap_annotated, unwrap_new_type
+from polyfactory.utils.helpers import (
+    get_annotation_metadata,
+    is_dataclass_instance,
+    unwrap_annotated,
+    unwrap_new_type,
+)
+from polyfactory.utils.normalize_type import normalize_type
 from polyfactory.utils.predicates import is_annotated
 from polyfactory.utils.types import NoneType
 
@@ -89,6 +95,10 @@ class FieldMeta:
         self.name = name
         self.constraints = constraints
 
+    def __repr__(self) -> str:
+        """Return a string representation of the field meta."""
+        return f"FieldMeta(name={self.name!r}, annotation={self.annotation!r}, default={self.default!r}, children={self.children!r}, constraints={self.constraints!r})"
+
     @functools.cached_property
     def type_args(self) -> tuple[Any, ...]:
         """Return the normalized type args of the annotation, if any.
@@ -139,11 +149,14 @@ class FieldMeta:
             ),
         )
 
+        annotation = normalize_type(annotation)
         annotated = is_annotated(annotation)
         if not constraints and annotated:
             metadata = cls.get_constraints_metadata(annotation)
             constraints = cls.parse_constraints(metadata)
 
+        # annotations can take many forms: Optional, an Annotated type, or anything with __args__
+        # in order to normalize the annotation, we need to unwrap the annotation.
         if not annotated and (origin := get_origin(annotation)) and origin in TYPE_MAPPING:
             container = TYPE_MAPPING[origin]
             annotation = container[get_args(annotation)]  # type: ignore[index]
@@ -168,7 +181,7 @@ class FieldMeta:
 
         for value in metadata:
             if is_annotated(value):
-                _, inner_metadata = unwrap_annotated(value, random=DEFAULT_RANDOM)
+                _, inner_metadata = unwrap_annotated(value)
                 constraints.update(cast("dict[str, Any]", cls.parse_constraints(metadata=inner_metadata)))
             elif func := getattr(value, "func", None):
                 if func is str.islower:
