@@ -1,3 +1,4 @@
+import warnings
 from datetime import datetime
 from decimal import Decimal
 from enum import Enum
@@ -462,3 +463,19 @@ def test_unsupported_type_engine() -> None:
         match="Unsupported type engine: Location()",
     ):
         factory.build()
+
+
+def test_check_deprecated_setting() -> None:
+    with pytest.warns(DeprecationWarning, match=r"Use of deprecated default '__set_relationships__'"):
+
+        class BookFactory(SQLAlchemyFactory[Book]): ...
+
+
+def test_check_deprecated_default_overridden_no_deprecation() -> None:
+    with warnings.catch_warnings():
+        warnings.simplefilter("error")
+
+        class BookFactory(SQLAlchemyFactory[Book]):
+            __set_relationships__ = False
+            __set_association_proxy__ = False
+            __check_model__ = False
