@@ -1,11 +1,12 @@
 from __future__ import annotations
 
 from dataclasses import dataclass, field
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Dict, Iterable, List, Optional, TypeVar, Union
 
 import pytest
 
 from pydantic import BaseModel, Field
+from pydantic import __version__ as pydantic_version
 
 from polyfactory.factories.dataclass_factory import DataclassFactory
 from polyfactory.factories.pydantic_factory import ModelFactory
@@ -19,7 +20,7 @@ class Node:
     value: int
     union_child: Union[Node, int]  # noqa: UP007
     list_child: List[Node]  # noqa: UP006
-    optional_child: Optional[Node]  # noqa: UP007
+    optional_child: Optional[Node]  # noqa: RUF100, UP007, UP045
     child: Node = field(default=_Sentinel)  # type: ignore[assignment]
 
     def __post_init__(self) -> None:
@@ -45,7 +46,7 @@ class PydanticNode(BaseModel):
     union_child: Union[PydanticNode, int]  # noqa: UP007
     list_child: List[PydanticNode]  # noqa: UP006
     optional_union_child: Union[PydanticNode, None]  # noqa: UP007
-    optional_child: Optional[PydanticNode]  # noqa: UP007
+    optional_child: Optional[PydanticNode]  # noqa: RUF100, UP007, UP045
     child: PydanticNode = Field(default=_Sentinel)  # type: ignore[assignment]
     recursive_key: Dict[PydanticNode, Any]  # noqa: UP006
     recursive_value: Dict[str, PydanticNode]  # noqa: UP006
@@ -88,3 +89,46 @@ def test_recursive_list_model() -> None:
     book_factory = DataclassFactory.create_factory(Book)
     assert book_factory.build().author.books == []
     assert book_factory.build(author=None).author is None
+
+
+@pytest.mark.skipif(pydantic_version.startswith("1"), reason="Pydantic v2+ is required for JsonValue")
+def test_recursive_type_annotation() -> None:
+    from pydantic import JsonValue
+
+    class RecursiveTypeModel(BaseModel):
+        json_value: JsonValue
+
+    factory = ModelFactory.create_factory(RecursiveTypeModel)
+    results = factory.batch(50)
+
+    valid_types = {int, str, bool, float, dict, list, type(None)}
+
+    assert _get_types(result.json_value for result in results) == valid_types
+    assert _get_types(result.json_value for result in factory.coverage()) == valid_types
+
+
+RecursiveType = Union[List["RecursiveType"], int]
+
+
+def test_recursive_model_with_forward_ref() -> None:
+    @dataclass
+    class RecursiveTypeModel:
+        json_value: RecursiveType
+
+    factory = DataclassFactory.create_factory(
+        RecursiveTypeModel,
+        __forward_references__={"RecursiveType": int},
+    )
+    results = factory.batch(50)
+
+    valid_types = {int, list}
+
+    assert _get_types(result.json_value for result in results) == valid_types
+    assert _get_types(result.json_value for result in factory.coverage()) == valid_types
+
+
+_T = TypeVar("_T")
+
+
+def _get_types(items: Iterable[_T]) -> set[type[_T]]:
+    return {type(item) for item in items}
